
var AppWindow = HomeWindow.extend({
	init: function(win) {
		// NOTE: Adding to window here so that we don't see a white screen at the beginning.
		win.add(Ti.UI.createImageView({
			image: Taazza.Media.Image.LOGO,
			width: 'auto',
			height: 'auto',
			left: 10,
			top: 5,
			zIndex: 5,
			enableZoomControls: false
		}));

		this._super(win);
	},

	updateCityAndWeather: function(results) {
		// NOTE: Deliberate extra space in the string below!
		Status.show(String.format(L('SM_UPDATE'), ' city & weather'));
		this.updateCity(results.places);
		this.updateWeatherStn(results.weather);
	},

	updateCity: function(city_json) {
		var cities = city_json.features;
		if (cities.length == 1) {
			var city = cities[0].properties;
			var city_feed_coords = cities[0].geometry.coordinates.reverse().join(',');
	//		Ti.API.debug(city);
			this.updateLocation();
			Ti.App.Properties.setString('city', city.title);
			Ti.App.Properties.setString('city_feed_id', city.tags[1]);
			Ti.App.Properties.setString('city_feed_coords', city_feed_coords);

			Ti.App.Properties.setString('current_feed_id', city.tags[1]);
			Ti.App.Properties.setString('current_feed_coords', city_feed_coords);
			this.win.fireEvent('refreshTabs', {all: true});
		}
	},

	updateWeatherStn: function(weather_json) {
	//	Ti.API.debug(weather_json);
		var stations = weather_json.features;
	//	Ti.API.debug(stations);
		if (stations.length == 1) {
	//		Ti.API.debug(stations[0]);
			var stn = stations[0].properties;
	//		Ti.API.debug(stn);
			Ti.App.Properties.setString('w_station', stations[0].id);
			Ti.App.Properties.setString('w_image', stn.image);
			Ti.App.Properties.setString('w_data', JSON.stringify(stn));
			this.w_last_fetched = new Date();
			Ti.App.Properties.setString('w_last_fetched', this.w_last_fetched.toUTCString());
			this.updateWeather();
		}
	},

	updateLocation: function() {
		this.addr = Taazza.Util.prunedAddress(Ti.App.Properties.getString('address'));
		this.locateLabel.text = this.addr[0];
	},

	updateWeather: function() {
		this.weatherImage.image = Taazza.Media.Image.for_weather(Ti.App.Properties.getString('w_image'));
	},

	show: function() {
		// Show weather section
		var weatherView = Ti.UI.createView({
			top: 0,
			right: 5,
			width: 50,
			height: 50,
			zIndex: 5
		});

		this.weatherImage = Ti.UI.createImageView({
			image: Taazza.Media.Image.NOWEATHER,
			defaultImage: Taazza.Media.Image.NOWEATHER,
			width: 'auto',
			height: 'auto',
			enableZoomControls: false
		});
		weatherView.add(this.weatherImage);
		this.win.add(weatherView);

		var ctx = this;
		// Add navigation buttons to the root window
		var buttonOptions = {
			top: 0,
			height: 50,
			left: 0,
			right: 55,
			color: '#459E00',
			backgroundColor: '#D7E5B5',
			backgroundImage: Taazza.Media.Image.HEADER,
			font: {fontFamily: 'Verdana',
			       fontSize: 14}
		};
		this.locateLabel = Ti.UI.createLabel({
			left: 80,
			right: 20,
			height: 45,
			text: '',
			textAlign: 'right',
			ellipsize: true,
			color: '#333',
			font: {fontFamily: 'Verdana',
			       fontSize: 16}
		});

		var locateDetail =  Ti.UI.createImageView({
			image: Taazza.Media.Image.DETAIL,
			width: 'auto',
			height: 'auto',
			right: 7,
			enableZoomControls: false
		});

		var locateRow = Ti.UI.createView(buttonOptions);
		locateRow.add(this.locateLabel);
		locateRow.add(locateDetail);
		locateRow.addEventListener('click', function() {
			ctx.openGPSWindow();
		});

		win.add(locateRow);

		if (Ti.App.Properties.hasProperty('address')) {
			this.updateLocation();
		} else {
			this.locateLabel.text = L('BT_LOCATE');
			this.openGPSWindow();
		}
	}
});

