
function APIClient(failureOpts)
{
	this.xhr = Ti.Network.createHTTPClient();
	this.xhr.setTimeout(60000);
	this.xhr.onerror = function(e) {
		Ti.API.error(e.error);
		Status.hideIndicator();
		if (failureOpts) {
			if (failureOpts.msg) {
				Status.show(failureOpts.msg, failureOpts.isError);
			}
			if (failureOpts.handler) {
				failureOpts.handler.call(failureOpts.context);
			}
		}
	};
}

APIClient.prototype.alertNoNetwork = function() {
	Status.hideIndicator();
	Status.show(L('SM_NO_NETWORK'));
};

APIClient.prototype.perform_request = function(http_method, url, options) {
	if (Ti.Network.online == false) {
		this.alertNoNetwork();
		return;
	}

	this.xhr.open(http_method, url);
	if (options && options.headers) {
		var headers = options.headers;
		for (var k in headers) {
			if (headers.hasOwnProperty(k)) {
				this.xhr.setRequestHeader(k, headers[k]);
			}
		}
	}
	if (options && options.data) {
		this.xhr.send(options.data);
	} else {
		this.xhr.send();
	}
};

APIClient.prototype.get = function(url, options) {
	this.perform_request('GET', url, options);
};

APIClient.prototype.post = function(url, options) {
	this.perform_request('POST', url, options);
};

function TixClient()
{
}

TixClient.ENDPOINT = (Ti.Platform.model == "google_sdk" ? "http://10.0.0.5/" : "http://app.taazza.com/tix/?");
TixClient.OCK = Ti.App.Properties.getString('key');

TixClient.prototype = new APIClient();

TixClient.prototype.constructor = TixClient;

TixClient.prototype.alertNoNetwork = function() {
};

TixClient.prototype.track = function(evt, props)
{
	this.xhr.onload = function(e) {
//		Ti.API.debug(this.responseText);
	};
	var params = "event=" + evt + '&ock=' + TixClient.OCK;
	for (var k in props) {
		if (props.hasOwnProperty(k)) {
			params += ("&" + (k + "=" + escape(props[k])));
		}
	}
	this.get(TixClient.ENDPOINT + params);
};

