
function geolocate(success_handler) {
	// NOTE: See http://developer.android.com/guide/topics/location/obtaining-user-location.html
	if (Ti.Geolocation.locationServicesEnabled == false) {
/*
		// NOTE: Show alert dialog asking whether we should open the Settings window
		var alertDialog = Ti.UI.createAlertDialog({
			title: 'Geolocation disabled',
			message: 'You need to enable geolocation on your device. Would you like to do it now?',
			buttonNames: ['No, thanks', 'Yes, please'],
			cancel: 0,
		});
		alertDialog.addEventListener('click', function(e) {
			Ti.API.info(e);
			if (!e.cancel) {
				var intent = Ti.Android.createIntent({
					action: Ti.Android.ACTION_MAIN,
					className: "com.android.settings.SecuritySettings",
					packageName: "com.android.settings",
				});
				intent.addCategory(Ti.Android.CATEGORY_LAUNCHER);
				Ti.Android.currentActivity.startActivity(intent);
			}
		});
		alertDialog.show();
*/
		success_handler.call(this, {geolocation_failure: {disabled: true}});

		return null;
	}

	Status.show(L('SM_LOCATE'));

	Ti.Geolocation.accuracy = Ti.Geolocation.ACCURACY_BEST;
	Ti.Geolocation.distanceFilter = 10;
	var geoerror = null,
	    current_position = null,
	    thandle = null;

	function cleanup_handler() {
		// Stop listening for GPS updates
		Ti.Geolocation.removeEventListener('location', location_handler);

		if (thandle !== null) {
			clearTimeout(thandle);
			thandle = null;
		}
	}

	function location_handler(e) {
		if (!e.success || e.error ||
		    (e.coords.latitude == 0 && e.coords.longitude == 0))
		{
//				Ti.API.error('ERROR: ' + JSON.stringify(e.error));
			Status.show(L('SM_LOCATE'));
			geoerror = e;
			return;
		}

		// In case, the handler is called twice.
		if (geoerror === false) {
			return;
		}

		geoerror = false;

		cleanup_handler();

//			Status.show('location: ' + e.coords.latitude + ',' + e.coords.longitude);

		success_handler.call(this, e);
	}

	function timeout_handler() {
		cleanup_handler();

		var msg = null, data = null;
		if (geoerror === null) {
			msg = String.format(L('SM_GPS_ERROR'), 'Timeout');
			data = {timeout: true};
		} else if (geoerror) {
			msg = String.format(L('SM_GPS_ERROR'), geoerror.error.message);
			data = {error: geoerror.error.message};
		}
		if (msg) {
			// Use cached position if available
			if (current_position) {
//					Status.show('current_position: ' + current_position.coords.latitude + ',' + current_position.coords.longitude);
				success_handler.call(this, current_position);
			} else {
				Status.show(msg, true);
				success_handler.call(this, {geolocation_failure: data});
			}
		} else {
			// TODO: Report to Hoptoad
			Ti.API.error('Unknown error in timeout_handler');
		}
	}

	// Save cached position if available
	Ti.Geolocation.getCurrentPosition(function(e) {
		if (!e.success || e.error ||
		    (e.coords.latitude == 0 && e.coords.longitude == 0)) {
			return;
		}

		current_position = e;
	});

	// Start listening for GPS updates
	Ti.Geolocation.addEventListener('location', location_handler);

	// Set maximum time for getting a GPS fix
	thandle = setTimeout(timeout_handler, 60000);

	return cleanup_handler;
}

function GoogleGeocoder() {}

GoogleGeocoder.prototype = new APIClient();

GoogleGeocoder.prototype.constructor = GoogleGeocoder;

GoogleGeocoder.prototype.base_url = "http://maps.googleapis.com/maps/api/geocode/json?";

GoogleGeocoder.prototype.geocode = function(opts, success_handler) {
	this.xhr.onload = function(e) {
//		Ti.API.debug(this.responseText);
		success_handler(JSON.parse(this.responseText));
	};
	var params = "region=in&sensor=true&language=en";
	for (var k in opts) {
		if (opts.hasOwnProperty(k)) {
			params += ("&" + (k + "=" + escape(opts[k])));
		}
	}
	this.get(this.base_url + params);
};

GoogleGeocoder.prototype.forward = function(address, success_handler) {
	this.geocode({address: address},
		     function(r) {
		     	var e = {};
		     	if (r.status == "OK" && r.results.length > 0) {
				e = r.results[0].geometry.location;
			}
			success_handler(e);
		     });
};

GoogleGeocoder.prototype.reverse = function(lat, lon, success_handler) {
	this.geocode({latlng: lat + "," + lon},
		     function(r) {
		     	var e = {places: []};

		     	if (r.status == "OK") {
				var t, j, cc, ac, addrs = [];
				for (var i=0; i < r.results.length; ++i) {
					t = r.results[i];
					skip = false;
					// Ignore country & state entries
					for (j = 0; j < t.types.length && !skip; ++j)
					{
						switch(t.types[j])
						{
						case 'country':
						case 'administrative_area_level_1':
							skip = true;
							break;
						}
					}
					// NOTE: Locations in Bangalore have a 'locality' type
					// formatted address which includes 560001. We will
					// have duplicate entries in the result set because
					// 'administrative_area_level_2' type differs only in
					// the presence of this pincode.
					if (skip || addrs.indexOf(t.formatted_address) != -1) {
						continue;
					}

					addrs.push(t.formatted_address);
					cc = "";
					for (j = t.address_components.length-1; j >= 0; --j) {
						ac = t.address_components[j];
						if (ac.types.indexOf('country') != -1) {
							cc = ac.short_name;
							break;
						}
					}
					e.places.push({country_code: cc,
						       address: t.formatted_address,
						       loc: t.geometry.location});
				}
			}
			success_handler(e);
		     });
};

