
var HomeWindow = Class.extend({
	init: function(win) {
		this.win = win;
		this.curLat = Ti.App.Properties.getString('latitude');
		this.curLon = Ti.App.Properties.getString('longitude');
		this.appLocateOrExit = false;

		this.addListeners();
	},

	addListeners: function() {
		var ctx = this;

		this.win.addEventListener('refreshTabs', function(e) {
			ctx.refreshTabs(e);
		});
	},

	refreshTabs: function(e) {
		var winObj = this.tabGroup.currentWinObj(), curTab = this.tabGroup.curTab;
		if (winObj) {
			if ((winObj.TYPENAME == 'CityListWindow' || winObj.TYPENAME == 'PlaceSearchWindow') && !winObj.win.visible) {
				var obj = winObj.fwinObj ? winObj.fwinObj : winObj.current_object.fwinObj;
				obj.fetch(true);
			} else {
				winObj.fetch(true);
			}
		}
		if (e && e.all) {
			this.tabGroup.refreshAll(curTab);
		}
	},

	refresh: function(data) {
	//	Ti.API.debug('[CALL] refresh');
		var latitude, longitude;
		if (data && data.latitude) {
			latitude = data.latitude;
			longitude = data.longitude;

			Ti.App.Properties.setString('latitude', latitude);
			Ti.App.Properties.setString('longitude', longitude);
			Ti.App.Properties.setString('address', data.address);
		} else {
	//		Ti.API.debug('Location unchanged');
			latitude = this.curLat;
			longitude = this.curLon;
		}

		if (!latitude) {
	//		Ti.API.debug('Not located yet');

			this.appLocateOrExit = true;
			return;
		}

		if (this.curLat == latitude && this.curLon == longitude) {
	//		Ti.API.debug('Current location chosen again');
			return;
		}

		Status.show(String.format(L('SM_UPDATE'), ''));
		var state = (this.curLat === null ? 'new' : 'changed');
		this.curLat = latitude;
		this.curLon = longitude;
		dummyButton.fireEvent('click', {latitude: latitude, longitude: longitude, state: state});
	},

	locateOrExit: function() {
		var ctx = this;
		if (!(this.curLat || this.curLon)) {
			var alertDialog = Ti.UI.createAlertDialog({
				title: L('DT_NEEDLOC'),
				message: L('DM_NEEDLOC'),
				buttonNames: [L('BT_LOCNO'), L('BT_LOCYES')],
				cancel: 0
			});
			alertDialog.addEventListener('click', function(e) {
				if (e.cancel) {
					win.close();
				} else {
					ctx.locWindow.open();
				}
			});
			alertDialog.show();
		}
	},

	openGPSWindow: function(e) {
		if (!this.locWindow) {
			this.locWindow = Ti.UI.createWindow({
				url: 'ui/LocationMiniWindow.js',
				backgroundColor: '#000',
				opacity: 0.8,
				gps_timer: null,
				'Taazza': Taazza,
				'Status': Status,
				'APIClient': APIClient
			});
			var ctx = this;
			this.locWindow.addEventListener('close', function(e) {
				var action = this.action,
				    gps_cleanup_handler = this.gps_cleanup_handler,
				    loc_data = this.loc_data;
				this.action = null;
				this.gps_cleanup_handler = null;
				this.visible = false;
				this.loc_data = null;
				switch (action)
				{
				case 'save':
					// NOTE: Save => Success or Timeout already fired.
					// Hence no need to clear timer
					gps_cleanup_handler = null;
					ctx.refresh(loc_data);
					break;

				case 'search':
					Taazza.openWindow({url: 'ui/LocationSearchWindow.js',
							   title: L('WT_LOCATE'),
							   listeners: {
							   	       'close': function(args) {
							   			ctx.refresh(this.loc_data);
								       }
								      }
							  });
					break;

				case null:
					break;

				default:
					ctx.locateOrExit();
					break;
				}
				if (gps_cleanup_handler) {
					gps_cleanup_handler();
				}
			});
		}
		this.locWindow.open();
	},

	// TODO: Is this needed?
	show: function() {
	}
});

