
var win = Ti.UI.currentWindow;
var Taazza = win.Taazza;
var Status = win.Status;
var APIClient = win.APIClient;

Taazza.Util.include('lib/geolocation.js');

win.backgroundColor = '#000';
win.opacity = 0.8;
win.visible = true;

function hideLoading() {
	win.loading_icon.animate(Ti.UI.createAnimation({
		transform: Ti.UI.create2DMatrix()
	}));
	win.loading_icon.hide();
}

function reverseGeocode(lat, lon)
{
	var geocoder = new GoogleGeocoder();
	geocoder.reverse(lat, lon, function(e)
	{
		hideLoading();
		if (e.places.length == 0) {
			// TODO: Issue should be title, action should be subtitle
			win.addr_title.text = L('SM_PICK');
			win.addr_subtitle.text = L('SM_LOCFAIL');
			Status.show(L('SM_LOCFAIL'), true);
			return;
		} else if (e.places[0].country_code.toUpperCase() != "IN") {
			win.addr_title.text = L('SM_PICK_INDIAN');
			win.addr_subtitle.text = L('SM_LOCONLYINDIA');
			Status.show(L('SM_LOCONLYINDIA'), true);
		} else {
			win.map.image = Taazza.Google.getStaticMap(lat, lon, 250, 100);
			win.map.show();
			var addr = e.places[0].address.replace(/,\s*India$/, '');
			var t = addr.split(',');
			var title = t[0];
			// TODO: Why is this 35? Need comment
			if (title.length > 35) {
				title = title.substr(0, 35) + "...";
			}
			win.addr_title.text = title;
			win.addr_subtitle.text = t.splice(1).join(',').replace(/^\s+/, '');
			win.loc_data = {latitude: lat,
					longitude: lon,
					address: addr};
			win.saveButton.title = L('BT_SAVE');
			win.saveHelp.text = L('HT_LOCSAVE');
		}
	});
}

function geolocate_handler(evt)
{
	if (evt.geolocation_failure) {
		var title = "", subtitle = "";
		if (evt.geolocation_failure.disabled) {
			title = L('SM_GPSOFF');
			subtitle = L('SM_ENABLEGPS');
		} else if (evt.geolocation_failure.timeout) {
			title = L('SM_GPSTIMEOUT');
			subtitle = L('SM_PICKMANUAL');
		} else if (evt.geolocation_failure.error) {
			title = L('SM_GPSOFF');
			subtitle = L('SM_PICKMANUAL');
		}
		win.addr_title.text = title;
		win.addr_subtitle.text = subtitle;
		hideLoading();
		win.map.image = Taazza.Media.Icon.ISSUE;
		win.map.show();
		win.searchHelp.text = L('HT_LOCPICK');
	} else {
		reverseGeocode(evt.coords.latitude, evt.coords.longitude);
	}
}

if (win.addr_title) {
	win.action = undefined;
	win.gps_cleanup_handler = null;
	win.map.hide();
	win.loading_icon.show();
	win.addr_title.text = L('SM_LOCATING');
	win.addr_subtitle.text = L('SM_WAIT');
	win.saveHelp.text = L('HT_TOOLONG');
	win.saveButton.title = L('BT_CANCEL');
	win.gps_cleanup_handler = geolocate(geolocate_handler);
} else {
	var view = Ti.UI.createView({
		width: 280,
		height: 260,
		layout: 'vertical',
		opacity: 0.95,
		backgroundColor: '#FFF',
		borderRadius: 4.0,
		borderColor: 'transparent',
		borderWidth: 1.0
	});
	win.add(view);

	var attrs = {left: 15,
		     color: '#000',
		     fontFamily: 'Verdana'};

	var header_view = Ti.UI.createView({top: 8});
	header_view.add(Ti.UI.createImageView({
		image: Taazza.Media.Icon.MARKER,
		width: 'auto',
		height: 'auto',
		left: 20
	}));

	var place_view = Ti.UI.createView({
		height: 50,
		left: 35,
		layout: 'vertical'
	});

	win.addr_title = Ti.UI.createLabel({
		text: L('SM_LOCATING'),
		top: 6,
		left: attrs.left,
		color: attrs.color,
		font: {fontFamily: attrs.fontFamily,
		       fontSize: 18}
	});
	place_view.add(win.addr_title);

	win.addr_subtitle = Ti.UI.createLabel({
		text: L('SM_WAIT'),
		left: attrs.left,
		color: attrs.color,
		font: {fontFamily: attrs.fontFamily,
		       fontSize: 10}
	});
	place_view.add(win.addr_subtitle);

	header_view.add(place_view);
	view.add(header_view);

	var center_view =  Ti.UI.createView({
		top: 20,
		height: 100
	});
	win.loading_icon = Ti.UI.createImageView({
		image: Taazza.Media.Image.LOADING,
		width: 'auto',
		height: 'auto'
	});
	center_view.add(win.loading_icon);

	// TODO: Animation runs only the first time you open the window. Make it run afresh.
	var t3 = Ti.UI.create2DMatrix();
	t3 = t3.rotate(360);
	var a = Ti.UI.createAnimation({
		duration: 1000,
		repeat: 100
	});
	a.transform = t3;
	win.loading_icon.animate(a);
	win.map = Ti.UI.createImageView({
		height: 'auto',
		width: 'auto',
		borderRadius: 6,
		borderColor: 'transparent',
		borderWidth: 1,
		preventDefaultImage: false,
		visible: false
	});
	center_view.add(win.map);
	view.add(center_view);

	var buttonOpts = {height: 35,
			  width: 75,
			  color: '#FFF',
			  backgroundColor: '#888',
			  borderRadius: 2.0,
			  borderColor: 'transparent',
			  borderWidth: 3.0,
			  font: {fontFamily: 'Verdana',
				 fontWeight: 'normal',
				 fontSize: 15}},
	    buttonHelpOpts = {color: '#888',
			      text: L('HT_MANUAL'),
			      height: 25,
			      font: {fontFamily: 'Verdana',
				     fontWeight: 'normal',
				     fontSize: 11}};

	buttonOpts.title = L('BT_SEARCH');
	var searchButton = Ti.UI.createButton(buttonOpts);
	searchButton.addEventListener('click', function() {
		win.action = 'search';
		win.close();
	});

	var searchButtonView = Ti.UI.createView({
		width: 90,
		left: 10,
		layout: 'vertical'
	});
	win.searchHelp = Ti.UI.createLabel(buttonHelpOpts);
	searchButtonView.add(win.searchHelp);
	searchButtonView.add(searchButton);

	buttonOpts.title = L('BT_CANCEL');
	buttonOpts.backgroundColor = Taazza.Conf.GREEN;
	win.saveButton = Ti.UI.createButton(buttonOpts);

	win.saveButton.addEventListener('click', function() {
		if (win.loc_data) {
			win.action = 'save';
		}
		win.close();
	});

	var saveButtonView = Ti.UI.createView({
		width: 90,
		right: 10,
		layout: 'vertical'
	});
	buttonHelpOpts.text = L('HT_TOOLONG');
	win.saveHelp = Ti.UI.createLabel(buttonHelpOpts);
	saveButtonView.add(win.saveHelp);
	saveButtonView.add(win.saveButton);
	
	var button_view = Ti.UI.createView({
		height: 60,
		top: 10,
		left: 15,
		right: 15
	});
	button_view.add(searchButtonView);
	button_view.add(saveButtonView);
	view.add(button_view);

	win.gps_cleanup_handler = geolocate(geolocate_handler);
}

