
var win = Ti.UI.currentWindow;

var Taazza = win.Taazza;
win.add(Taazza.getTitleBar(L('WT_LOCATE')));

var Status = win.Status;
var APIClient = win.APIClient;

Taazza.Util.include('lib/geolocation.js');

win.addEventListener('open', function(e) {
	var a = [];
	var curLat = 22.0, curLon = 82.0, latDelta = 10.0, lonDelta = 10.0, xm, ym;

	if (Ti.App.Properties.hasProperty('latitude')) {
		// FIXME: If user changes location within the app, these variables need to get updated
		curLat = parseFloat(Ti.App.Properties.getString('latitude'));
		curLon = parseFloat(Ti.App.Properties.getString('longitude'));

		var curLoc = Ti.Map.createAnnotation({
			latitude: curLat,
			longitude: curLon,
			title: L('AT_URLOC'),
			subtitle: Ti.App.Properties.getString('address'),
			pinImage: Taazza.Media.Marker.ORANGE,
			animate: true
		});

		latDelta = lonDelta = 0.08;
		a.push(curLoc);
		xm = 0.05/320;
		ym = 0.05/480;
	}
	var mapView = Ti.Map.createView({
		top: 90,
		mapType: Ti.Map.STANDARD_TYPE,
		region: {latitude: curLat + 5.0, longitude: curLon,
			 latitudeDelta: latDelta, longitudeDelta: lonDelta},
		location: {latitude: curLat + 5.0, longitude: curLon,
			   latitudeDelta: latDelta, longitudeDelta: lonDelta},
		animate: true,
		regionFit: true,
		userLocation: true,
		annotations: a
	});
	mapView.addEventListener('click', function(e) {
		Ti.API.info('click');
		Status.show('click');
		Ti.API.info(e);
		Ti.API.info(this.region);
		Ti.API.info(this.location);
	});
	win.add(mapView);

	var fakeMapView = Ti.UI.createView({
		top: 90,
		bottom: 50,
		opacity: 0.9,
		zIndex: 10,
	});

	fakeMapView.addEventListener('touchstart', function(e) {
		Ti.API.info('fakeMapView: touchstart');
		Ti.API.info(e);
		this.start = {x: e.x, y: e.y};
	});

	fakeMapView.addEventListener('touchend', function(e) {
		Ti.API.info('fakeMapView: touchend');
		Ti.API.info(e);
		var start = this.start;
		this.start = null;
		var xd = (e.x - start.x) * xm,
		    yd = (start.y - e.y) * ym;
		Ti.API.info(xd + ' ' + yd);
		curLat += yd;
		curLon += xd;
		mapView.setLocation({latitude: curLat, longitude: curLon,
			   	     latitudeDelta: latDelta, longitudeDelta: lonDelta});
	});
	fakeMapView.addEventListener('dblclick', function(e) {
		Ti.API.info('fakeMapView: dblclick');
		Ti.API.info(e);
		var xd = (e.x - 160) * xm,
		    yd = (170 - e.y) * ym;
		Ti.API.info(xd + ' ' + yd);
		var lat = curLat + yd,
		    lon = curLon + xd;
		Ti.API.info(lat + ' ' + lon);
		mapView.addAnnotation(Ti.Map.createAnnotation({
			latitude: lat,
			longitude: lon,
			pinImage: Taazza.Media.Marker.ORANGE,
		}));
	});
	win.add(fakeMapView);

	if (a.length > 0) {
		mapView.selectAnnotation(a[0]);
	}

	var mapInfoView = Ti.UI.createView({
		bottom: 0,
		height: 65,
		zIndex: 5,
		backgroundColor: '#FFF',
		borderColor: '#AAA',
		borderWidth: 1,
		visible: false
	});
	var mapInfoImage = Ti.UI.createImageView({
		image: Taazza.Media.Icon.AROUND,
		left: 2,
		width: 'auto',
		height: 'auto'
	});
	mapInfoView.add(mapInfoImage);
	var mapInfoTitle = Ti.UI.createLabel({
		width: 200,
		top: 5,
		left: 50,
		color: '#333',
		font: {fontFamily: 'Verdana',
		       fontSize: 14,
		       fontWeight: 'bold'}
	});
	mapInfoView.add(mapInfoTitle);
	var mapInfoSubTitle = Ti.UI.createLabel({
		width: 200,
		top: 35,
		left: 50,
		color: '#888',
		font: {fontFamily: 'Verdana',
		       fontSize: 10}
	});
	mapInfoView.add(mapInfoSubTitle);
	var saveButton = Ti.UI.createButton({
		width: 60,
		height: 30,
		right: 5,
		title: L('BT_SAVE'),
		color: '#FFF',
		backgroundColor: Taazza.Conf.GREEN,
		borderRadius: 2.0,
		borderColor: Taazza.Conf.GREEN,
		borderWidth: 3.0,
		font: {fontFamily: 'Verdana',
		       fontSize: 14,
		       fontWeight: 'bold'}
	});
	saveButton.addEventListener('click', function(e) {
		win.loc_data = saveButton.annotation;
		win.close();
	});
	mapInfoView.add(saveButton);
	win.add(mapInfoView);

	var searchBar = Ti.UI.createView({
		top: 42,
		height: 48,
		zIndex: 5,
		backgroundColor: '#000',
		opacity: 0.7
	});
	var locateMe = Ti.UI.createButton({
		left: 5,
		width: 38,
		height: 48,
		image: Taazza.Media.Icon.LOCATE
	});
	locateMe.addEventListener('click', function(e) {
		this.blur();
		geolocate(function(evt) {
			if (evt.geolocation_failure) {
				if (evt.geolocation_failure.disabled) {
					Status.show(L('SM_GPSENABLE'), true);
				}
			} else {
				reverseGeocode(evt.coords.latitude, evt.coords.longitude);
			}
		});
	});

	searchBar.add(locateMe);

	var search = Ti.UI.createButton({
		right: 5,
		width: 38,
		height: 48,
		image: Taazza.Media.Icon.SEARCH,
		backgroundDisabledImage: Taazza.Media.Icon.SEARCH,
		enabled: true
	});
	searchBar.add(search);
	var locField = Ti.UI.createTextField({
		left: 45,
		height: 38,
		right: 45,
		hintText: L('HT_LOCATION'),
		font: {fontFamily: 'Verdana',
		       fontSize: 12},
		rightButton: search,
		rightButtonMode: Ti.UI.INPUT_BUTTONMODE_ALWAYS
	});
	searchBar.add(locField);

	win.add(searchBar);

	var loc = null;
	var locTips = [{title: L('LT_GPS'),
			subtitle: L('LST_LOCATE'),
			icon: Taazza.Media.Icon.LOCATION,
			left: 2,
			backgroundColor: 'transparent',
			click_listener: function() { locateMe.fireEvent('click'); }},
		       {title: L('LT_SEARCH'),
			subtitle: L('LST_LOCATION'),
			icon: Taazza.Media.Icon.SEARCHING,
			left: 10,
			backgroundColor: 'transparent',
			click_listener: function() { locField.focus(); }},
		       {title: L('LT_NOTFIND'),
			subtitle: L('LST_LOCTIP'),
			icon: Taazza.Media.Icon.TIP,
			left: 5,
			backgroundColor: '#D7E5B5'}];
	for (var i=0; i < 3; ++i)
	{
		var tip = locTips[i];
		var row = Ti.UI.createTableViewRow({
			height: 50,
			className: 'tipitem' + i,
			touchEnabled: false,
			backgroundColor: tip.backgroundColor
		});
		var tView = Ti.UI.createView({
			height: 50
		});
		tView.add(Ti.UI.createImageView({
			left: tip.left,
			image: tip.icon,
			width: 'auto',
			height: 'auto'
		}));
		tView.add(Ti.UI.createLabel({
			text: tip.title,
			left: 55,
			width: 245,
			top: 10,
			color: '#333',
			font: {fontFamily: 'Verdana',
			       fontSize: 12,
			       fontWeight: 'bold'}
		}));
		tView.add(Ti.UI.createLabel({
			text: tip.subtitle,
			left: 55,
			right: 20,
			top: 27,
			color: '#888',
			font: {fontFamily: 'Verdana',
			       fontSize: 10}
		}));
		row.add(tView);
		if (tip.click_listener) {
			row.addEventListener('click', tip.click_listener);
		}
		locTips[i] = row;
	}
	var locList = Ti.UI.createTableView({
		height: 102,
		top: 90,
		zIndex: 10,
		backgroundColor: '#EEE',
		color: '#333',
		font: {fontFamily: 'Verdana',
		       fontSize: 12},
		data: locTips.slice(0, 2),
		borderColor: '#AAA',
		borderWidth: 1
	});
	locList.addEventListener('click', function(e) {
		if (!e.row.lat) {
			return;
		}

		if (loc) {
			mapView.removeAnnotation(loc);
		}
		mapView.region = {latitude: e.row.lat, longitude: e.row.lon,
				  latitudeDelta: 0.08, longitudeDelta: 0.08};
		mapView.location = mapView.region;
		loc = Ti.Map.createAnnotation({
			latitude: e.row.lat,
			longitude: e.row.lon,
			title: e.row.title,
			subtitle: e.row.subtitle,
			pinImage: Taazza.Media.Marker.ORANGE,
			animate: true,
			address: e.row.address
		});
		mapView.addAnnotation(loc);
		locList.hide();
		mapView.selectAnnotation(loc);
		var c = Taazza.Util.prunedAddress(e.row.address);
		mapInfoTitle.text = c[0];
		mapInfoSubTitle.text = c[1];
		saveButton.annotation = loc;
		mapInfoView.show();
	});
	win.add(locList);

	// NOTE: Provides a unique id for each geocoding attempt
	var locCount = 0;

	var geocoder = new GoogleGeocoder();

	function reverseGeocode(lat, lon)
	{
		geocoder.reverse(lat, lon, function(e)
		{
			var addrs = [];
			var nonIndianLoc = false;
/*
			for (var i=0; i < e.places.length; i++) {
				Ti.API.info(e.places[i].address);
			}
*/
			for (var i = (e.places.length > 5 ? e.places.length-5 : 0); i < e.places.length; i++) {
				if (e.places[i].country_code.toUpperCase() != "IN") {
					nonIndianLoc = true;
					continue;
				}
				var addr = e.places[i].address.replace(/,\s*India$/, '');
				var t = addr.split(',');
				var title = t[0];
				// TODO: Why is this 35?
				if (title.length > 35) {
					title = title.substr(0, 35) + "...";
				}
				var subtitle = t.splice(1).join(',').replace(/^\s+/, '');
				var row = Ti.UI.createTableViewRow({
					height: 50,
					className: 'item' + locCount + "_" + i
				});
				var tView = Ti.UI.createView({
					height: 50
				});
				var imgView = Ti.UI.createImageView({
					left: 17,
					image: Taazza.Media.Icon.BLACK_MARKER,
					width: 'auto',
					height: 'auto'
				});
				tView.add(imgView);
				tView.add(Ti.UI.createImageView({
					image: Taazza.Media.Image.DETAIL,
					right: 7,
					width: 'auto',
					height: 'auto'
				}));
				tView.add(Ti.UI.createLabel({
					text: title,
					left: 55,
					top: 10,
					width: 245,
					color: '#333',
					font: {fontFamily: 'Verdana',
					       fontSize: 12,
					       fontWeight: 'bold'}
				}));
				tView.add(Ti.UI.createLabel({
					text: subtitle,
					left: 55,
					right: 20,
					top: 25,
					color: '#888',
					font: {fontFamily: 'Verdana',
					       fontSize: 10}
				}));
				row.add(tView);
				row.title = title;
				row.subtitle = subtitle;
				row.lat = lat;
				row.lon = lon;
				row.address = addr;
				addrs.push(row);
			}
			if (nonIndianLoc && addrs.length == 0) {
				Status.show(L('SM_LOCONLYINDIA'), true);
			} else {
				addrs.push(locTips[2]);
				locList.height = addrs.length * 51;
				locList.setData(addrs);
				locList.show();
			}

			// NOTE: Enable the search button
			search.enabled = true;
			locCount += 1;
		});
	}

	search.addEventListener('click', function (e) {
		if (!this.enabled) {
			return;
		}

		if (!locField.value || locField.value == "") {
			Status.show(L('SM_LOCNEEDED'), true);
			return;
		}

		this.blur();
		this.enabled = false;
		locList.hide();
		mapInfoView.hide();
		Status.show(L('SM_LOCATE'));

		geocoder.forward(locField.value, function(evt) {
			if (!evt.lat) {
				// NOTE: Enable the search button
				search.enabled = true;
				Status.show(String.format(L('SM_LOCNOTFOUND'), locField.value), true);
				return;
			}

			reverseGeocode(evt.lat, evt.lng);
		});
	});
});
